@@ -23,12 +23,15 @@
 #include <ksharedconfig.h>
 #include <kconfiggroup.h>
 #include <kdebug.h>
+#include <kglobal.h>
 #include <QCache>
 
+typedef QCache<QString, KSharedConfig::Ptr> ConfigCache;
+K_GLOBAL_STATIC_WITH_ARGS(ConfigCache , static_cache, (15))
 
 static KSharedConfig::Ptr retrieve_from_cache(const QString& filename, const char *resourceType="config") 
 {
-	static QCache<QString, KSharedConfig::Ptr> cache(25);
+	QCache<QString, KSharedConfig::Ptr> &cache = *static_cache;
 	if (cache.contains(filename)) 
 		return *cache[filename];
 	KSharedConfig::Ptr m = KSharedConfig::openConfig (filename , KConfig::NoGlobals, resourceType );
@@ -36,6 +39,11 @@ static KSharedConfig::Ptr retrieve_from_cache(const QString& filename, const cha
 	return m;
 }
 
+void KNotifyConfig::clearCache()
+{
+    static_cache->clear();
+}
+
 
 KNotifyConfig::KNotifyConfig( const QString & _appname, const ContextList & _contexts, const QString & _eventid )
 	: appname (_appname),
